@@ -5,7 +5,7 @@ CREATE FUNCTION query (x int) RETURNS text
 LANGUAGE plsh
 AS $$
 #!/bin/sh
-if which psql >/dev/null; then
+if command -v psql >/dev/null; then
     psql -X -At -c "select b from pbar where a = $1"
 else
     echo 'no PATH?' 1>&2
